@@ -110,6 +110,7 @@ async def _op(model, op, reqtype, delete=False, **kwargs):
         return r
 
 
+# XXX once we require Python 3.7, this should be a dataclass.
 class BaseModelObject:
     """Base class for all pythonized model objects."""
     def __init__(self, **kwargs):
@@ -125,7 +126,13 @@ class BaseModelObject:
         return self.__dict__ == other.__dict__
 
     def __hash__(self):
-        return hash(self.__dict__)
+        return hash((x[1] for x in sorted(self.__dict__.items())))
+
+    def replace(self, **kwargs):
+        """Return a copy of this object with some fields updated."""
+        args = self.__dict__.copy()
+        args.update(kwargs)
+        return self.__class__(**args)
 
 
 class PreseemModel:
